CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_sigmaM.c File Reference

CCL

Macros | Functions
ccl_test_sigmaM.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`
`#include <stdio.h>`
`#include <math.h>`

## Macros
#define | SIGMAM_TOLERANCE 1.0E-4

## Functions
| CTEST_DATA (sigmam)
| CTEST_SETUP (sigmam)
| CTEST2 (sigmam, model_1)
| CTEST2 (sigmam, model_2)
| CTEST2 (sigmam, model_3)

## Macro Definition Documentation

## ◆ SIGMAM_TOLERANCE

#define SIGMAM_TOLERANCE 1.0E-4

## Function Documentation

## ◆ CTEST2() [1/3]

CTEST2 | ( | sigmam | ,
|  | model_1 |
| ) |  |

## ◆ CTEST2() [2/3]

CTEST2 | ( | sigmam | ,
|  | model_2 |
| ) |  |

## ◆ CTEST2() [3/3]

CTEST2 | ( | sigmam | ,
|  | model_3 |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | sigmam |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | sigmam |  | ) |